#! /bin/csh

# Simple sed script to convert POPC and POPE charmm files to amber format
# Also converts charmm waters and ions to amber format

# Run as: ./convert_charmm.x input_pdb output_pdb 

set input_pdb = $1
set output_pdb = $2

if ($#argv != 2) then
   echo "Please run as:"
   echo "`basename $0` <input_pdb> <output_pdb>"
   exit(1)
endif

if (! -e $input_pdb) then
  echo "Input file: $input_pdb does not exist."
  exit(1)
endif

if ($#argv == 2) then
echo "		     Converting charmm POPC   "
echo "				       POPE   "
echo "				       waters " 
echo "				       ions   "
echo " 	              to amber readable format ....."
else
echo "		     Please run as:                 "
echo "	             `basename $0` <input_pdb> <output_pdb>"
exit(1)
endif

cp $1 $2

# Rename POPC residue to PPC
sed -i 's/POPC/PPC /g' $2

# Rename POPE residue to PPE
sed -i 's/POPE/PPE /g' $2

# Rename charmm waters to amber convention
sed -i 's/OH2 TIP3/O   WAT /g' $2
sed -i 's/H1  TIP3/H1  WAT /g' $2
sed -i 's/H2  TIP3/H2  WAT /g' $2

# Rename charmm potassium, sodium and chorine ions to amber convention
sed -i 's/CLA CLA/Cl- Cl-/g' $2
sed -i 's/SOD SOD/Na+ Na+/g' $2
sed -i 's/POT POT/K+  K+ /g' $2

echo "                    "
echo "		      Done"
